==> logger_36-2024.20-py3-none-any.whl: logger_36/task/format/message.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2023
SEE COPYRIGHT NOTICE BELOW
"""

import typing as h

from logger_36.config.message import (
    ELAPSED_TIME_FORMAT,
    LEVEL_CLOSING,
    LEVEL_OPENING,
    MEMORY_FORMAT,
    MESSAGE_MARKER,
)
from logger_36.constant.generic import NOT_PASSED
from logger_36.constant.message import EXPECTED_OP, expected_op_h


def MessageFormat(with_where: bool, with_memory_usage: bool, /) -> str:
    """"""
    output = [
        f"%(asctime)s"
        f"{LEVEL_OPENING}%(level_first_letter)s{LEVEL_CLOSING}\t"
        f"{MESSAGE_MARKER}%(message)s"
    ]

    if with_where:
        output.append("%(where)s")
    output.append(ELAPSED_TIME_FORMAT)
    if with_memory_usage:
        output.append(MEMORY_FORMAT)

    return "".join(output)


def FormattedMessage(
    message: str,
    /,
    *,
    actual: h.Any = NOT_PASSED,
    expected: h.Any | None = None,
    expected_op: expected_op_h = "=",
    with_final_dot: bool = True,
) -> str:
    """"""
    if expected_op not in EXPECTED_OP:
        raise ValueError(
            FormattedMessage(
                'Invalid "expected" section operator',
                actual=expected_op,
                expected=f"One of {str(EXPECTED_OP)[1:-1]}",
            )
        )

    if actual is NOT_PASSED:
        if with_final_dot:
            if message[-1] != ".":
                message += "."
        elif message[-1] == ".":
            message = message[:-1]

        return message

    if message[-1] == ".":
        message = message[:-1]
    actual = _FormattedValue(actual)
    expected = _FormattedValue(expected)

    if with_final_dot:
        dot = "."
    else:
        dot = ""
    return f"{message}: Actual={actual}; Expected{expected_op}{expected}{dot}"


def _FormattedValue(value: h.Any, /, *, should_format_str: bool = True) -> str:
    """"""
    if value is None:
        return "None"

    if isinstance(value, str):
        if should_format_str:
            return f'"{value}"'
        return value

    return str(value)


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> logger_36-2024.23-py3-none-any.whl: logger_36/task/format/message.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2023
SEE COPYRIGHT NOTICE BELOW
"""

import difflib as diff
import typing as h

from logger_36.config.message import (
    ELAPSED_TIME_FORMAT,
    LEVEL_CLOSING,
    LEVEL_OPENING,
    MEMORY_FORMAT,
    MESSAGE_MARKER,
)
from logger_36.constant.generic import NOT_PASSED
from logger_36.constant.message import EXPECTED_OP, expected_op_h


def MessageFormat(with_where: bool, with_memory_usage: bool, /) -> str:
    """"""
    output = [
        f"%(asctime)s"
        f"{LEVEL_OPENING}%(level_first_letter)s{LEVEL_CLOSING}\t"
        f"{MESSAGE_MARKER}%(message)s"
    ]

    if with_where:
        output.append("%(where)s")
    output.append(ELAPSED_TIME_FORMAT)
    if with_memory_usage:
        output.append(MEMORY_FORMAT)

    return "".join(output)


def FormattedMessage(
    message: str,
    /,
    *,
    actual: h.Any = NOT_PASSED,
    expected: h.Any | None = None,
    expected_is_choices: bool = False,
    expected_op: expected_op_h = "=",
    with_final_dot: bool = True,
) -> str:
    """"""
    if expected_op not in EXPECTED_OP:
        raise ValueError(
            FormattedMessage(
                'Invalid "expected" section operator',
                actual=expected_op,
                expected=f"One of {str(EXPECTED_OP)[1:-1]}",
            )
        )

    if actual is NOT_PASSED:
        if with_final_dot:
            if message[-1] != ".":
                message += "."
        elif message[-1] == ".":
            message = message[:-1]

        return message

    if message[-1] == ".":
        message = message[:-1]
    expected = _FormattedExpected(expected_op, expected, expected_is_choices, actual)
    if with_final_dot:
        dot = "."
    else:
        dot = ""

    return f"{message}: Actual={actual}:{type(actual).__name__}; {expected}{dot}"


def _FormattedExpected(
    operator: str, expected: h.Any, expected_is_choices: bool, actual: h.Any, /
) -> str:
    """"""
    if isinstance(expected, h.Sequence) and expected_is_choices:
        close_matches = diff.get_close_matches(actual, expected)
        if close_matches.__len__() > 0:
            close_matches = ", ".join(close_matches)
            return f"Close matche(s): {close_matches}"
        else:
            expected = ", ".join(map(str, expected))
            return f"Valid values: {expected}"
    else:
        if operator == "=":
            stripe = f":{type(expected).__name__}"
        else:
            stripe = ""
            if operator == ":":
                operator = ": "
        return f"Expected{operator}{expected}{stripe}"


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
